backup

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 10, 2019 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Backuper

type Backuper interface {
	// Backup files to w. Returns the number of files which were backed up.
	Backup(logger golog.Logger, w *tar.Writer) (int, error)
}

Backuper performs the action of backing up a file.

type FilesBackuper

type FilesBackuper struct {
	// Cfg configures which files to backup.
	Cfg config.FileConfig
}

FilesBackuper backs up files.

func (FilesBackuper) Backup

func (b FilesBackuper) Backup(logger golog.Logger, w *tar.Writer) (int, error)

Backup configured files.

type PrometheusBackuper

type PrometheusBackuper struct {
	// Cfg for Prometheus backup job.
	Cfg config.PrometheusConfig
}

PrometheusBackuper backs up a Prometheus database. By taking a snapshot with the Prometheus admin API and backing its contents up under the data directory path.

func (PrometheusBackuper) Backup

func (b PrometheusBackuper) Backup(logger golog.Logger, w *tar.Writer) (int, error)

Backup Prometheus database.

Jump to