Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Backuper ¶
type Backuper interface {
// Backup files to w. Returns the number of files which were backed up.
Backup(logger golog.Logger, w *tar.Writer) (int, error)
}
Backuper performs the action of backing up a file.
type FilesBackuper ¶
type FilesBackuper struct {
// Cfg configures which files to backup.
Cfg config.FileConfig
}
FilesBackuper backs up files.
type PrometheusBackuper ¶
type PrometheusBackuper struct {
// Cfg for Prometheus backup job.
Cfg config.PrometheusConfig
}
PrometheusBackuper backs up a Prometheus database. By taking a snapshot with the Prometheus admin API and backing its contents up under the data directory path.
Click to show internal directories.
Click to hide internal directories.